@@ -435,7 +435,7 @@ class GraspNet():
         y2 = len(masky) - np.argmax(masky[::-1]) 
         return (x1, y1, x2, y2)
 
-    def loadScenePointCloud(self, sceneId, camera, annId, align=False, format='open3d', use_workspace=False):
+    def loadScenePointCloud(self, sceneId, camera, annId, align=False, format = 'open3d', use_workspace = False, use_mask = False):
         '''
         **Input:**
 
@@ -451,6 +451,7 @@ class GraspNet():
 
         - use_workspace: bool of whether crop the point cloud in the work space.
 
+        - use_mask: bool of thether crop the point cloud use mask(z>0).
 
         **Output:**
 
@@ -487,8 +488,9 @@ class GraspNet():
 
         mask = (points_z > 0)
         points = np.stack([points_x, points_y, points_z], axis=-1)
-        points = points[mask]
-        colors = colors[mask]
+        if use_mask:
+            points = points[mask]
+            colors = colors[mask]
         if align:
             points = transform_points(points, camera_pose)
         if format == 'open3d':
